===================================================
``psyclone.tests.test_files.dummy_transformations``
===================================================

.. automodule:: psyclone.tests.test_files.dummy_transformations

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.test_files.dummy_transformations
